summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--newgrf.c27
-rw-r--r--openttd.h1
2 files changed, 19 insertions, 9 deletions
diff --git a/openttd.h b/openttd.h
index 5bf21c3ce..c61a64dfc 100644
--- a/openttd.h
+++ b/openttd.h
@@ -67,6 +67,7 @@ typedef uint16 TownID;
typedef byte PlayerID;
typedef byte OrderID;
typedef byte CargoID;
+typedef byte LandscapeID;
typedef uint16 StringID;
typedef uint32 SpriteID; ///< The number of a sprite, without mapping bits and colortables
typedef uint32 PalSpriteID; ///< The number of a sprite plus all the mapping bits and colortables
diff --git a/newgrf.c b/newgrf.c
index 989c14dd4..8f26af7d6 100644
--- a/newgrf.c
+++ b/newgrf.c
@@ -1050,6 +1050,11 @@ static bool BridgeChangeInfo(uint brid, int numinfo, int prop, byte **bufp, int
return ret;
}
+static bool CargosChangeInfo(uint gvid, int numinfo, int prop, byte **bufp, int len)
+{
+ return false;
+}
+
static bool GlobalVarChangeInfo(uint gvid, int numinfo, int prop, byte **bufp, int len)
{
byte *buf = *bufp;
@@ -1098,15 +1103,19 @@ static void VehicleChangeInfo(byte *buf, int len)
/* TODO: Bridges, town houses. */
static const VCI_Handler handler[] = {
/* GSF_TRAIN */ RailVehicleChangeInfo,
/* GSF_ROAD */ RoadVehicleChangeInfo,
/* GSF_SHIP */ ShipVehicleChangeInfo,
/* GSF_AIRCRAFT */ AircraftVehicleChangeInfo,
/* GSF_STATION */ StationChangeInfo,
/* GSF_CANAL */ NULL,
/* GSF_BRIDGE */ BridgeChangeInfo,
/* GSF_TOWNHOUSE */NULL,
/* GSF_GLOBALVAR */GlobalVarChangeInfo,
};
uint8 feature;
@@ -1098,15 +1103,19 @@ static void VehicleChangeInfo(byte *buf, int len)
/* TODO: Bridges, town houses. */
static const VCI_Handler handler[] = {
- /* GSF_TRAIN */ RailVehicleChangeInfo,
- /* GSF_ROAD */ RoadVehicleChangeInfo,
- /* GSF_SHIP */ ShipVehicleChangeInfo,
- /* GSF_AIRCRAFT */ AircraftVehicleChangeInfo,
- /* GSF_STATION */ StationChangeInfo,
- /* GSF_CANAL */ NULL,
- /* GSF_BRIDGE */ BridgeChangeInfo,
- /* GSF_TOWNHOUSE */NULL,
- /* GSF_GLOBALVAR */GlobalVarChangeInfo,
+ /* GSF_TRAIN */ RailVehicleChangeInfo,
+ /* GSF_ROAD */ RoadVehicleChangeInfo,
+ /* GSF_SHIP */ ShipVehicleChangeInfo,
+ /* GSF_AIRCRAFT */ AircraftVehicleChangeInfo,
+ /* GSF_STATION */ StationChangeInfo,
+ /* GSF_CANAL */ NULL,
+ /* GSF_BRIDGE */ BridgeChangeInfo,
+ /* GSF_TOWNHOUSE */ NULL,
+ /* GSF_GLOBALVAR */ GlobalVarChangeInfo,
+ /* GSF_INDUSTRYTILES */NULL,
+ /* GSF_INDUSTRIES */ NULL,
+ /* GSF_CARGOS */ CargosChangeInfo,
+ /* GSF_SOUNDFX */ NULL,
};
uint8 feature;